pub enum SystemUserData<'a> {
BackendAdmin {
system_user: SystemUserId,
},
BackendBackup {
system_user: &'a SystemUserId,
ssh_authorized_key: &'a AuthorizedKeyEntry,
},
BackendHermeticMetrics {
system_user: &'a SystemUserId,
},
BackendMetrics {
system_user: &'a SystemUserId,
ssh_authorized_key: &'a AuthorizedKeyEntry,
},
BackendSign {
system_user: &'a SystemUserId,
ssh_authorized_key: &'a AuthorizedKeyEntry,
},
BackendUpdate {
system_user: &'a SystemUserId,
ssh_authorized_key: &'a AuthorizedKeyEntry,
},
HostDownloadNetworkConfig {
system_user: &'a SystemUserId,
ssh_authorized_key: &'a AuthorizedKeyEntry,
},
HostShareholder {
system_user: &'a SystemUserId,
ssh_authorized_key: &'a AuthorizedKeyEntry,
},
Unknown {
system_user: SystemUserId,
ssh_authorized_keys: Vec<AuthorizedKeyEntry>,
home_dir: PathBuf,
},
}Expand description
The available data on system users on a Signstar host or its configuration.
Variants
BackendAdmin
The system user is used to do administrative tasks on a Signstar backend.
Note
This user must not be setup for remote login.
Fields
system_user: SystemUserIdThe system user.
BackendBackup
The system user is used to handle backup tasks for a Signstar backend.
BackendHermeticMetrics
The system user is used to deal with the metrics of a Signstar backend.
Note
This user must not be setup for remote login.
Fields
system_user: &'a SystemUserIdThe system user.
BackendMetrics
The system user is used to deal with the metrics of a Signstar backend.
BackendSign
The system user is used for signing operations with a Signstar backend.
BackendUpdate
The system user is used for the upload of Signstar backend firmware updates.
HostDownloadNetworkConfig
The system user is used to download network config data.
The system user is used to handle shares of a shared secret.
Unknown
It is not known what the system user is used for.
Note
This variant is commonly used for all system user information derived from a host.
Implementations
Sourceimpl<'a> SystemUserData<'a>
impl<'a> SystemUserData<'a>
Sourcepub fn system_user(&'a self) -> &'a SystemUserId
pub fn system_user(&'a self) -> &'a SystemUserId
Returns a reference to the tracked SystemUserId.
Returns a list of references to tracked AuthorizedKeyEntry.