pub struct SystemUserHostState<'a> {
pub(crate) system_user_data: HashSet<SystemUserData<'a>>,
}Expand description
The state of a host.
Fields
system_user_data: HashSet<SystemUserData<'a>>Implementations
Sourceimpl<'a> SystemUserHostState<'a>
impl<'a> SystemUserHostState<'a>
Sourcepub const STATE_NAME: &'static str = "system"
pub const STATE_NAME: &'static str = "system"
The name of the origin for the state.
Sourcepub fn new() -> Result<Self, Error>
pub fn new() -> Result<Self, Error>
Creates a new SystemUserHostState from system users and associated data on the host.
Note
The user data collected from the current system is always of the form
SystemUserData::Unknown, because without further context we cannot know (yet) whether a
given system user is supposed to be used by the Signstar system or not.
Safety
Uses unsafe functions to retrieve the user data on the current system (see
[uzers::all_users] for details).
Errors
Returns an error if
- a user record cannot be created from an item in
/etc/passwd - a file with SSH authorized keys cannot be read
- a file with SSH authorized keys contains an invalid SSH authorized key
Sourcepub fn system_user_data(&self) -> &HashSet<SystemUserData<'a>>
pub fn system_user_data(&self) -> &HashSet<SystemUserData<'a>>
Returns a reference to the set of SystemUserData.