pub enum BackendUserIdKind {
Any,
Admin,
Backup,
Metrics,
NonAdmin,
Observer,
Signing,
}Expand description
The kind of backend user.
This distinguishes between the different access rights levels (i.e. administrative and non-administrative) and roles (e.g. backup, metrics, signing) of a backend user.
Variants
Any
Any user.
Admin
Administrative user.
Backup
Backup user.
Metrics
Metrics user.
NonAdmin
Any non-administrative user.
Observer
User used to observe keys, without access to them.
Signing
Signing user.