pub enum SystemUserMapping {
ShareHolder {
system_user: SystemUserId,
ssh_authorized_key: AuthorizedKeyEntry,
},
WireGuardDownload {
system_user: SystemUserId,
ssh_authorized_key: AuthorizedKeyEntry,
},
}Expand description
Variants
A user for up and downloading shares of a shared secret.
WireGuardDownload
A system user, with SSH access, not mapped to any backend user, that is used for downloading the WireGuard configuration of the host.
Fields

system_user: SystemUserIdThe name of the system user.
The list of SSH public keys used for connecting to the system_user.