Config

Struct Config 

pub struct Config {
    system: SystemConfig,
    nethsm: Option<NetHsmConfig>,
    yubihsm2: Option<YubiHsm2Config>,
}
The configuration of a Signstar system.

Tracks system-wide configuration items, as well as configurations for specific backends.

Fields

system: SystemConfig

System configuration object.

nethsm: Option<NetHsmConfig>

Optional configuration object for NetHSM backends.

Note

Only supported when using the nethsm feature.

yubihsm2: Option<YubiHsm2Config>

Optional configuration object for YubiHSM2 backends.

Note

Only supported when using the yubihsm2 feature.

Implementations

Source

impl Config

pub fn user_backend_connection( &self, user: &SystemUserId, ) -> Option<UserBackendConnection>

Returns the optional UserBackendConnection matching a SystemUserId.

pub fn user_backend_connections( &self, filters: &[UserBackendConnectionFilter], ) -> Vec<UserBackendConnection>

Returns a list of UserBackendConnection objects matching a set of filters.

If no filters are provided, returns all available UserBackendConnection objects of all backends.

Beyond filtering for specific backend types, it is possible to only return administrative or non-administrative objects.

Source

impl Config

pub const DEFAULT_CONFIG_DIR: &str = "/usr/share/signstar/"

The default config directory below “/usr/”.

pub const RUN_OVERRIDE_CONFIG_DIR: &str = "/run/signstar/"

The override config directory below “/run/”.

pub const ETC_OVERRIDE_CONFIG_DIR: &str = "/etc/signstar/"

The override config directory below “/etc/”.

pub const CONFIG_NAME: &str = "config"

The configuration file name (without file type suffix).

pub fn default_system_path() -> PathBuf

Returns the default location of the Signstar configuration file on a system.

pub fn first_existing_system_path() -> Result<PathBuf, Error>

Returns the first found path of a Signstar configuratino on the system.

Errors

Returns an error if no configuration file is found.

pub fn list_config_dirs() -> Vec<PathBuf>

Returns the list of supported directory paths in which configuration files may reside.

The returned list of paths is sorted in increasing precedence.

pub fn list_config_file_paths() -> Vec<PathBuf>

Returns the list of supported configuration file paths.

The returned list of paths is sorted in increasing precedence.

fn from_yaml_str(s: &str) -> Result<Self, Error>

Creates a new Config from a string slice containing YAML data.

Errors

Returns an error if deserialization or validation fails.

fn from_yaml_file(path: impl AsRef<Path>) -> Result<Self, Error>

Creates a new Config from a file containing YAML data.

Errors

Returns an error if

  • the file does not exist
  • deserialization or validation fails.
pub fn from_file_path(path: impl AsRef<Path>) -> Result<Self, Error>

Creates a new Config from a file path.

Errors

Returns an error if

  • path has no file extension
  • path does not use one of the supported file extensions
  • creating a Config from the data fails
  • validating a Config created from the data fails
pub fn from_system_path() -> Result<Self, Error>

Creates a new Config from the first found Signstar configuration file path on the system.

Note

Uses Config::first_existing_system_path to determine the first existing Signstar configuration file path.

Errors

Returns an error if Config creation from the found path fails.

pub fn to_yaml_string(&self) -> Result<String, Error>

Serializes self as a YAML string.

Errors

Returns an error if serialization fails.

pub fn system(&self) -> &SystemConfig

Returns a reference to the SystemConfig.

pub fn nethsm(&self) -> Option<&NetHsmConfig>

Returns a reference to the NetHsmConfig.

pub fn yubihsm2(&self) -> Option<&YubiHsm2Config>

Returns a reference to the YubiHsm2Config.