pub trait BackendDomainFilter { }Expand description
An interface to define a generic filter when evaluating the domains of a backend.
pub trait BackendDomainFilter { }An interface to define a generic filter when evaluating the domains of a backend.