pub struct NetHsmAdminCredentials {
iteration: u32,
backup_passphrase: Passphrase,
unlock_passphrase: Passphrase,
administrators: Vec<FullCredentials>,
namespace_administrators: Vec<FullCredentials>,
}Expand description
Administrative credentials.
Tracks the following credentials and passphrases:
- the backup passphrase of the backend,
- the unlock passphrase of the backend,
- the top-level administrator credentials of the backend,
- the namespace administrator credentials of the backend.
Note
The unlock and backup passphrase must be at least 10 characters long. The passphrases of top-level and namespace administrator accounts must be at least 10 characters long. The list of top-level administrator credentials must include an account with the username “admin”.
Fields
iteration: u32backup_passphrase: Passphraseunlock_passphrase: Passphraseadministrators: Vec<FullCredentials>namespace_administrators: Vec<FullCredentials>Implementations
Sourceimpl NetHsmAdminCredentials
impl NetHsmAdminCredentials
Sourcepub fn new(
iteration: u32,
backup_passphrase: Passphrase,
unlock_passphrase: Passphrase,
administrators: Vec<FullCredentials>,
namespace_administrators: Vec<FullCredentials>,
) -> Result<Self, Error>
pub fn new( iteration: u32, backup_passphrase: Passphrase, unlock_passphrase: Passphrase, administrators: Vec<FullCredentials>, namespace_administrators: Vec<FullCredentials>, ) -> Result<Self, Error>
Creates a new NetHsmAdminCredentials instance.
Examples
use nethsm::FullCredentials;
use signstar_config::NetHsmAdminCredentials;
let creds = NetHsmAdminCredentials::new(
1,
"backup-passphrase".parse()?,
"unlock-passphrase".parse()?,
vec![FullCredentials::new(
"admin".parse()?,
"admin-passphrase".parse()?,
)],
vec![FullCredentials::new(
"ns1~admin".parse()?,
"ns1-admin-passphrase".parse()?,
)],
)?;Sourcepub fn get_iteration(&self) -> u32
pub fn get_iteration(&self) -> u32
Returns the iteration.
Sourcepub fn get_backup_passphrase(&self) -> &str
pub fn get_backup_passphrase(&self) -> &str
Returns the backup passphrase.
Sourcepub fn get_unlock_passphrase(&self) -> &str
pub fn get_unlock_passphrase(&self) -> &str
Returns the unlock passphrase.
Sourcepub fn get_administrators(&self) -> &[FullCredentials]
pub fn get_administrators(&self) -> &[FullCredentials]
Returns the list of administrators.
Sourcepub fn get_default_administrator(&self) -> Result<&FullCredentials, Error>
pub fn get_default_administrator(&self) -> Result<&FullCredentials, Error>
Returns the default system-wide administrator “admin”.
Errors
Returns an error if no administrative account with the system-wide [UserId] “admin” is
found.
Sourcepub fn get_namespace_administrators(&self) -> &[FullCredentials]
pub fn get_namespace_administrators(&self) -> &[FullCredentials]
Returns the list of namespace administrators.