NetHsmUserMapping

Enum NetHsmUserMapping 

pub enum NetHsmUserMapping {
    Admin(UserId),
    Backup {
        backend_user: SystemWideUserId,
        ssh_authorized_key: AuthorizedKeyEntry,
        system_user: SystemUserId,
    },
    HermeticMetrics {
        backend_users: NetHsmMetricsUsers,
        system_user: SystemUserId,
    },
    Metrics {
        backend_users: NetHsmMetricsUsers,
        ssh_authorized_key: AuthorizedKeyEntry,
        system_user: SystemUserId,
    },
    Signing {
        backend_user: UserId,
        signing_key_id: KeyId,
        key_setup: SigningKeySetup,
        ssh_authorized_key: AuthorizedKeyEntry,
        system_user: SystemUserId,
        tag: String,
    },
}
User and data mapping between system users and NetHSM users.

Variants



Admin(UserId)

A NetHsm user in the Administrator role, without a system user mapped to it.



Backup

A system user, with SSH access, mapped to a system-wide NetHSM user in the Backup role.

Fields

backend_user: SystemWideUserId

The name of the NetHSM user.

ssh_authorized_key: AuthorizedKeyEntry

The SSH public key used for connecting to the system_user.

system_user: SystemUserId

The name of the system user.



HermeticMetrics

A system user, without SSH access, mapped to a system-wide NetHSM user in the Metrics role and one or more NetHsm users in the Operator role with read-only access to zero or more keys.

Fields

backend_users: NetHsmMetricsUsers

The NetHSM users in the [Metrics][UserRole::Metrics] and [operator][UserRole::Operator] role.

system_user: SystemUserId

The name of the system user.



Metrics

A system user, with SSH access, mapped to a system-wide NetHSM user in the Metrics role and n users in the Operator role with read-only access to zero or more keys.

Fields

backend_users: NetHsmMetricsUsers

The NetHSM users in the [Metrics][UserRole::Metrics] and [operator][UserRole::Operator] role.

ssh_authorized_key: AuthorizedKeyEntry

The SSH public key used for connecting to the system_user.

system_user: SystemUserId

The name of the system user.



Signing

A system user, with SSH access, mapped to a NetHSM user in the Operator role with access to a single signing key.

Signing key and NetHSM user are mapped using a tag.

Fields

backend_user: UserId

The name of the NetHSM user.

signing_key_id: KeyId

The ID of the NetHSM key.

key_setup: SigningKeySetup

The setup of a NetHSM key.

ssh_authorized_key: AuthorizedKeyEntry

The SSH public key used for connecting to the system_user.

system_user: SystemUserId

The name of the system user.

tag: String

The tag used for the user and the signing key on the NetHSM.

Implementations

Source

impl NetHsmUserMapping

pub fn namespaces(&self) -> Vec<&NamespaceId>

Returns the list of [NamespaceId]s associated with this NetHsmUserMapping.

pub fn tag(&self, namespace: Option<&NamespaceId>) -> Option<&str>

Returns the optional tag used in the NetHsmUserMapping.

Note

Only NetHsmUserMapping::Signing can have a tag.

pub fn nethsm_user_ids(&self) -> Vec<UserId>

Returns the list of [UserId] objects associated with this NetHsmUserMapping.

pub fn nethsm_user_data<'a>(&'a self) -> HashSet<NetHsmUserData<'a>>

Returns the list of NetHsmUserData objects associated with this NetHsmUserMapping.

pub fn nethsm_user_key_data<'a>( &'a self, filter: NetHsmUserKeysFilter, ) -> Option<NetHsmUserKeyData<'a>>

Returns a filtered list of NetHsmUserKeyData objects from this NetHsmUserMapping.

Based on a NetHsmUserKeysFilter it is possible to target only namespaced or system-wide, or all user mappings that have associated key configs.