NetHsmAdminCredentials

Struct NetHsmAdminCredentials 

pub struct NetHsmAdminCredentials {
    iteration: u32,
    backup_passphrase: Passphrase,
    unlock_passphrase: Passphrase,
    administrators: Vec<FullCredentials>,
    namespace_administrators: Vec<FullCredentials>,
}
Administrative credentials.

Tracks the following credentials and passphrases:

  • the backup passphrase of the backend,
  • the unlock passphrase of the backend,
  • the top-level administrator credentials of the backend,
  • the namespace administrator credentials of the backend.

Note

The unlock and backup passphrase must be at least 10 characters long. The passphrases of top-level and namespace administrator accounts must be at least 10 characters long. The list of top-level administrator credentials must include an account with the username “admin”.

Fields

iteration: u32backup_passphrase: Passphraseunlock_passphrase: Passphraseadministrators: Vec<FullCredentials>namespace_administrators: Vec<FullCredentials>

Implementations

Source

impl NetHsmAdminCredentials

pub const BACKUP_PASSPHRASE_POLICY: PassphrasePolicy

The default PassphrasePolicy for a backup passphrase.

pub const UNLOCK_PASSPHRASE_POLICY: PassphrasePolicy

The default PassphrasePolicy for a backup passphrase.

pub const ADMIN_PASSPHRASE_POLICY: PassphrasePolicy

The default PassphrasePolicy for an admin passphrase.

pub fn new( iteration: u32, backup_passphrase: Passphrase, unlock_passphrase: Passphrase, administrators: Vec<FullCredentials>, namespace_administrators: Vec<FullCredentials>, ) -> Result<Self, Error>

Creates a new NetHsmAdminCredentials instance.

Examples
use nethsm::FullCredentials;
use signstar_config::nethsm::NetHsmAdminCredentials;

let creds = NetHsmAdminCredentials::new(
    1,
    "backup-passphrase-really-just-for-testing-i-promise".parse()?,
    "unlock-passphrase-really-just-for-testing-i-promise".parse()?,
    vec![FullCredentials::new(
        "admin".parse()?,
        "admin-passphrase-really-just-for-testing-i-promise".parse()?,
    )],
    vec![FullCredentials::new(
        "ns1~admin".parse()?,
        "ns1-admin-passphrase-really-just-for-testing-i-promise".parse()?,
    )],
)?;
pub fn unlock_passphrase(&self) -> &Passphrase

Returns the unlock passphrase.

pub fn administrators(&self) -> &[FullCredentials]

Returns the list of administrators.

pub fn default_administrator(&self) -> Result<&FullCredentials, Error>

Returns the default system-wide administrator “admin”.

Errors

Returns an error if no administrative account with the system-wide UserId “admin” is found.

pub fn namespace_administrators(&self) -> &[FullCredentials]

Returns the list of namespace administrators.

pub fn administrators_in_config( &self, config: &NetHsmConfig, ) -> Vec<&FullCredentials>

Returns the list of system-wide administrators, also present in a NetHsmConfig.

Retrieves the list of NetHsmUserMapping instances that represent system-wide administrators from config. Filters out all UserIds that cannot be matched and emits warnings for all unmatched ones.

pub fn namespace_administrators_in_config( &self, config: &NetHsmConfig, ) -> Vec<&FullCredentials>

Returns the list of namespace administrators, also present in a NetHsmConfig.

Retrieves the list of NetHsmUserMapping instances that represent namespace administrators from config. Filters out all UserIds that cannot be matched and emits warnings for all unmatched ones.