pub struct NetHsmBackendState {
pub(crate) user_states: Vec<UserState>,
pub(crate) key_states: Vec<KeyState>,
}Expand description
The state of a NetHsmBackend.
This tracks the available backend users, their roles and assigned tags, and the key setups associated with users.
Fields
user_states: Vec<UserState>The user states.
key_states: Vec<KeyState>The key states.
Implementations
Sourceimpl NetHsmBackendState
impl NetHsmBackendState
Sourcepub const STATE_NAME: &'static str = "NetHSM backend"
pub const STATE_NAME: &'static str = "NetHSM backend"
The name of the origin for the state.