pub enum StateDiffFailureTarget {
One,
Other,
}Expand description
The target of an asymmetric StateDiffFailure.
Asymmetric failure types are those, where a state is present in one, but not another state
origin (i.e. StateDiffFailure::DoesNotExist).
Here, the target allows to mark the state origin that introduces the asymmetry (e.g. by not providing state that another state origin offers).
Variants