pub enum ConfigFileVariant {
Show 30 variants
NoBackendAdminPlaintextNonAdminPlaintext,
NoBackendAdminPlaintextNonAdminSystemdCreds,
NoBackendAdminSystemdCredsNonAdminPlaintext,
NoBackendAdminSystemdCredsNonAdminSystemdCreds,
NoBackendAdminSssNonAdminPlaintext,
NoBackendAdminSssNonAdminSystemdCreds,
OnlyNetHsmBackendAdminPlaintextNonAdminPlaintext,
OnlyNetHsmBackendAdminPlaintextNonAdminSystemdCreds,
OnlyNetHsmBackendAdminSystemdCredsNonAdminPlaintext,
OnlyNetHsmBackendAdminSystemdCredsNonAdminSystemdCreds,
OnlyNetHsmBackendAdminSssNonAdminPlaintext,
OnlyNetHsmBackendAdminSssNonAdminSystemdCreds,
OnlyYubiHsm2BackendAdminPlaintextNonAdminPlaintext,
OnlyYubiHsm2BackendAdminPlaintextNonAdminSystemdCreds,
OnlyYubiHsm2BackendAdminSystemdCredsNonAdminPlaintext,
OnlyYubiHsm2BackendAdminSystemdCredsNonAdminSystemdCreds,
OnlyYubiHsm2BackendAdminSssNonAdminPlaintext,
OnlyYubiHsm2BackendAdminSssNonAdminSystemdCreds,
OnlyYubiHsm2MockHsmBackendAdminPlaintextNonAdminPlaintext,
OnlyYubiHsm2MockHsmBackendAdminPlaintextNonAdminSystemdCreds,
OnlyYubiHsm2MockHsmBackendAdminSystemdCredsNonAdminPlaintext,
OnlyYubiHsm2MockHsmBackendAdminSystemdCredsNonAdminSystemdCreds,
OnlyYubiHsm2MockHsmBackendAdminSssNonAdminPlaintext,
OnlyYubiHsm2MockHsmBackendAdminSssNonAdminSystemdCreds,
AllBackendsAdminPlaintextNonAdminPlaintext,
AllBackendsAdminPlaintextNonAdminSystemdCreds,
AllBackendsAdminSystemdCredsNonAdminPlaintext,
AllBackendsAdminSystemdCredsNonAdminSystemdCreds,
AllBackendsAdminSssNonAdminPlaintext,
AllBackendsAdminSssNonAdminSystemdCreds,
}Expand description
The Signstar configuration file variant used for the file contents.
Variants
NoBackendAdminPlaintextNonAdminPlaintext
No HSM backend.
- plaintext for administrative secrets
- plaintext for non-administrative secrets
NoBackendAdminPlaintextNonAdminSystemdCreds
No HSM backend.
- plaintext for administrative secrets
- systemd-creds for non-administrative secrets
NoBackendAdminSystemdCredsNonAdminPlaintext
No HSM backend.
- systemd-creds for administrative secrets
- plaintext for non-administrative secrets
NoBackendAdminSystemdCredsNonAdminSystemdCreds
No HSM backend.
- systemd-creds for administrative secrets
- systemd-creds for non-administrative secrets
NoBackendAdminSssNonAdminPlaintext
No HSM backend.
- Shamir’s Secret Sharing for administrative secrets
- plaintext for non-administrative secrets
NoBackendAdminSssNonAdminSystemdCreds
No HSM backend.
- Shamir’s Secret Sharing for administrative secrets
- systemd-creds for non-administrative secrets
OnlyNetHsmBackendAdminPlaintextNonAdminPlaintext
NetHSM backend.
- plaintext for administrative secrets
- plaintext for non-administrative secrets
OnlyNetHsmBackendAdminPlaintextNonAdminSystemdCreds
NetHSM backend.
- plaintext for administrative secrets
- systemd-creds for non-administrative secrets
OnlyNetHsmBackendAdminSystemdCredsNonAdminPlaintext
NetHSM backend.
- systemd-creds for administrative secrets
- plaintext for non-administrative secrets
OnlyNetHsmBackendAdminSystemdCredsNonAdminSystemdCreds
NetHSM backend.
- systemd-creds for administrative secrets
- systemd-creds for non-administrative secrets
OnlyNetHsmBackendAdminSssNonAdminPlaintext
NetHSM backend.
- Shamir’s Secret Sharing for administrative secrets
- plaintext for non-administrative secrets
OnlyNetHsmBackendAdminSssNonAdminSystemdCreds
NetHSM backend.
- Shamir’s Secret Sharing for administrative secrets
- systemd-creds for non-administrative secrets
OnlyYubiHsm2BackendAdminPlaintextNonAdminPlaintext
YubiHSM2 backend.
- plaintext for administrative secrets
- plaintext for non-administrative secrets
OnlyYubiHsm2BackendAdminPlaintextNonAdminSystemdCreds
YubiHSM2 backend.
- plaintext for administrative secrets
- systemd-creds for non-administrative secrets
OnlyYubiHsm2BackendAdminSystemdCredsNonAdminPlaintext
YubiHSM2 backend.
- systemd-creds for administrative secrets
- plaintext for non-administrative secrets
OnlyYubiHsm2BackendAdminSystemdCredsNonAdminSystemdCreds
YubiHSM2 backend.
- systemd-creds for administrative secrets
- systemd-creds for non-administrative secrets
OnlyYubiHsm2BackendAdminSssNonAdminPlaintext
YubiHSM2 backend.
- Shamir’s Secret Sharing for administrative secrets
- plaintext for non-administrative secrets
OnlyYubiHsm2BackendAdminSssNonAdminSystemdCreds
YubiHSM2 backend.
- Shamir’s Secret Sharing for administrative secrets
- systemd-creds for non-administrative secrets
OnlyYubiHsm2MockHsmBackendAdminPlaintextNonAdminPlaintext
YubiHSM2 mockhsm backend.
- plaintext for administrative secrets
- plaintext for non-administrative secrets
OnlyYubiHsm2MockHsmBackendAdminPlaintextNonAdminSystemdCreds
YubiHSM2 mockhsm backend.
- plaintext for administrative secrets
- systemd-creds for non-administrative secrets
OnlyYubiHsm2MockHsmBackendAdminSystemdCredsNonAdminPlaintext
YubiHSM2 mockhsm backend.
- systemd-creds for administrative secrets
- plaintext for non-administrative secrets
OnlyYubiHsm2MockHsmBackendAdminSystemdCredsNonAdminSystemdCreds
YubiHSM2 mockhsm backend.
- systemd-creds for administrative secrets
- systemd-creds for non-administrative secrets
OnlyYubiHsm2MockHsmBackendAdminSssNonAdminPlaintext
YubiHSM2 mockhsm backend.
- Shamir’s Secret Sharing for administrative secrets
- plaintext for non-administrative secrets
OnlyYubiHsm2MockHsmBackendAdminSssNonAdminSystemdCreds
YubiHSM2 mockhsm backend.
- Shamir’s Secret Sharing for administrative secrets
- systemd-creds for non-administrative secrets
AllBackendsAdminPlaintextNonAdminPlaintext
NetHSM and YubiHSM2 backends.
- plaintext for administrative secrets
- plaintext for non-administrative secrets
AllBackendsAdminPlaintextNonAdminSystemdCreds
NetHSM and YubiHSM2 backends.
- plaintext for administrative secrets
- systemd-creds for non-administrative secrets
AllBackendsAdminSystemdCredsNonAdminPlaintext
NetHSM and YubiHSM2 backends.
- systemd-creds for administrative secrets
- plaintext for non-administrative secrets
AllBackendsAdminSystemdCredsNonAdminSystemdCreds
NetHSM and YubiHSM2 backends.
- systemd-creds for administrative secrets
- systemd-creds for non-administrative secrets
AllBackendsAdminSssNonAdminPlaintext
NetHSM and YubiHSM2 backends.
- Shamir’s Secret Sharing for administrative secrets
- plaintext for non-administrative secrets
AllBackendsAdminSssNonAdminSystemdCreds
NetHSM and YubiHSM2 backends.
- Shamir’s Secret Sharing for administrative secrets
- systemd-creds for non-administrative secrets
Implementations
Sourceimpl ConfigFileVariant
impl ConfigFileVariant
Sourcepub fn as_config_bytes(&self) -> &[u8] ⓘ
pub fn as_config_bytes(&self) -> &[u8] ⓘ
Returns the bytes of a Signstar configuration matching the chosen variant.