pub struct ConfigFileConfig {
pub location: Option<ConfigFileLocation>,
pub variant: ConfigFileVariant,
pub system_user_config: Option<SystemUserConfig>,
}Expand description
Configuration for how and where to provide a Signstar configuration file.
Fields
location: Option<ConfigFileLocation>The optional location in which the Signstar config is placed.
If location is None, the Signstar config is not written to a file.
variant: ConfigFileVariantThe variant of Signstar configuration that is added.
system_user_config: Option<SystemUserConfig>The optional configuration for system users.
Note
When set, this implies the creation of all system users.