pub struct YubiHsm2AdminCredentials {
iteration: u32,
backup_passphrase: Passphrase,
administrators: Vec<Credentials>,
}Expand description
Administrative credentials for YubiHSM2 backends.
Tracks the following items:
- the minimum iteration for which the credentials should apply,
- the backup passphrase of the backend,
- the administrator credentials of the backend,
Note
There must be at least one set of [Credentials] in the list of administrators.
The passphrases of administrator accounts must be at least
Self::MINIMUM_PASSPHRASE_LENGTH_USER characters long.
The backup passphrase must be at least Self::MINIMUM_PASSPHRASE_LENGTH_BACKUP characters
long.
It is implied, that the administrator users of a YubiHSM2 backend have the necessary capabilities for the creation of other users and keys.
Fields
iteration: u32backup_passphrase: Passphraseadministrators: Vec<Credentials>Implementations
Sourceimpl YubiHsm2AdminCredentials
impl YubiHsm2AdminCredentials
Sourcepub const DEFAULT_ID: u16 = 1
pub const DEFAULT_ID: u16 = 1
The default ID on an unprovisioned YubiHSM2 device.
Sourcepub const DEFAULT_PASSPHRASE: &str = "password"
pub const DEFAULT_PASSPHRASE: &str = "password"
The default passphrase on an unprovisioned YubiHSM2 device.
Sourcepub const MINIMUM_PASSPHRASE_LENGTH_USER: usize = 8
pub const MINIMUM_PASSPHRASE_LENGTH_USER: usize = 8
The default passphrase on an unprovisioned YubiHSM2 device.
Sourcepub const MINIMUM_PASSPHRASE_LENGTH_BACKUP: usize = 10
pub const MINIMUM_PASSPHRASE_LENGTH_BACKUP: usize = 10
The minimum length of a backup passphrase.
Sourcepub fn new(
iteration: u32,
backup_passphrase: Passphrase,
administrators: Vec<Credentials>,
) -> Result<Self, Error>
pub fn new( iteration: u32, backup_passphrase: Passphrase, administrators: Vec<Credentials>, ) -> Result<Self, Error>
Creates a new YubiHsm2AdminCredentials.
Errors
Returns an error if
- there is no administrator user,
- a user passphrase is too short,
- or the backup passphrase is too short.