are_admin_creds_usable

Function are_admin_creds_usable 

fn are_admin_creds_usable(
    runner: &ScenarioRunner,
    credentials: &Credentials,
) -> bool
Return true if given administrative credentials are currently usable.

Returns false if the credentials cannot be used, have no object information, or do not match the capabilities or domains they should have.