get_key_ids

Function get_key_ids 

fn get_key_ids(
    runner: &ScenarioRunner,
    credentials: &Credentials,
    object_type: ObjectType,
) -> Result<Vec<Id>, Error>
Returns a list of Ids that are of a specific [ObjectType].

Note

Only Ids of keys visible to the provided Credentials are returned.

Errors

Returns an error, if

  • running a scenario fails
  • there is a logic error in the value(s) returned by the backend