struct UserMappingsAndCredentials<'config, 'creds>(Vec<(&'config YubiHsm2UserMapping, &'creds Credentials)>);Expand description
A list of user mappings and their credentials for a YubiHSM2.
Note
This type does not inherently distinguish between user mappings for administrative and non-administrative users!
Use Self::new_from_non_admin to create this struct for non-administrative user mappings and
Self::new_from_admin to create it for administrative user mappings.
Tuple Fields
0: Vec<(&'config YubiHsm2UserMapping, &'creds Credentials)>Implementations
Sourceimpl<'config, 'creds> UserMappingsAndCredentials<'config, 'creds>
impl<'config, 'creds> UserMappingsAndCredentials<'config, 'creds>
Sourcepub fn new_from_non_admin(
config: &'config YubiHsm2Config,
creds: &'creds [Credentials],
) -> Result<Self, Error>
pub fn new_from_non_admin( config: &'config YubiHsm2Config, creds: &'creds [Credentials], ) -> Result<Self, Error>
Creates a new UserMappingsAndCredentials for the non-administrative user mappings in a
YubiHsm2Config and a list of Credentials.
Errors
Returns an error if
- there are duplicates in
creds - not every user mapping has credentials assigned to it
- not every credentials have user mappings assigned to them
Sourcepub fn new_from_admin(
config: &'config YubiHsm2Config,
creds: &'creds YubiHsm2AdminCredentials,
) -> Result<Self, Error>
pub fn new_from_admin( config: &'config YubiHsm2Config, creds: &'creds YubiHsm2AdminCredentials, ) -> Result<Self, Error>
Creates a new UserMappingsAndCredentials for the administrative user mappings in a
YubiHsm2Config and the administrative credentials of a YubiHsm2AdminCredentials.
Errors
Returns an error if
- there are duplicates in
creds - not every user mapping has credentials assigned to it
- not every credentials have user mappings assigned to them