YubiHsm2UserMapping

Enum YubiHsm2UserMapping 

pub enum YubiHsm2UserMapping {
    Admin {
        authentication_key_id: Id,
    },
    AuditLog {
        authentication_key_id: Id,
        ssh_authorized_key: AuthorizedKeyEntry,
        system_user: SystemUserId,
    },
    Backup {
        authentication_key_id: Id,
        wrapping_key_id: Id,
        ssh_authorized_key: AuthorizedKeyEntry,
        system_user: SystemUserId,
    },
    HermeticAuditLog {
        authentication_key_id: Id,
        system_user: SystemUserId,
    },
    Signing {
        authentication_key_id: Id,
        key_setup: SigningKeySetup,
        domain: Domain,
        signing_key_id: Id,
        ssh_authorized_key: AuthorizedKeyEntry,
        system_user: SystemUserId,
    },
}
User and data mapping between system users and YubiHSM2 users.

Variants



Admin

A YubiHSM2 user in the administrator role, without a system user mapped to it.

Tracks an authentication key object with a specific authentication_key_id.

Note

This variant implies, that the created authentication key object has all relevant capabilities necessary for the creation of users and keys and to restore from backup, i.e.:

  • delete-asymmetric-key
  • generate-asymmetric-key
  • put-asymmetric-key
  • delete-authentication-key
  • put-authentication-key
  • change-authentication-key
  • get-option
  • set-option
  • delete-hmac-key
  • generate-hmac-key
  • put-mac-key
  • sign-hmac
  • verify-hmac
  • delete-opaque
  • generate-opaque
  • get-opaque
  • put-opaque
  • reset-device
  • delete-template
  • get-template
  • put-template
  • delete-wrap-key
  • exportable-under-wrap
  • generate-wrap-key
  • import-wrapped
  • put-wrap-key
  • unwrap-data
  • wrap-data
  • put-public-wrap-key
  • delete-public-wrap-key
  • generate-symmetric-key
  • put-symmetric-key
  • delete-symmetric-key

Further, it is assumed that the authentication key object is added to all domains.

Fields

authentication_key_id: Id

The identifier of the authentication key used to create a session with the YubiHSM2.



AuditLog

A system user, with SSH access, mapped to a YubiHSM2 authentication key.

This variant tracks

  • an authentication key object with a specific authentication_key_id
  • an SSH authorized key with a specific ssh_authorized_key
  • a system user ID using system_user

Its data is used to create relevant system and backend users for the retrieval of audit logs over the network, made available by the YubiHSM2.

Note

This variant implies, that the created authentication key object has all relevant capabilities for audit log retrieval (i.e. get-log-entries).

Fields

authentication_key_id: Id

The identifier of the authentication key used to create a session with the YubiHSM2.

ssh_authorized_key: AuthorizedKeyEntry

The SSH public key used for connecting to the system_user.

system_user: SystemUserId

The name of the system user.



Backup

A mapping used for the creation of YubiHSM2 backups.

This variant tracks

  • an [authentication key object] with a specific authentication_key_id
  • a wrap key object with a specific wrapping_key_id
  • an SSH authorized key with a specific ssh_authorized_key
  • a system user ID using system_user

Its data is used to create relevant system and backend users for the creation of backups of all keys (including [authentication key object]s) and non-key material (e.g. OpenPGP certificates) of a YubiHSM2.

Note

This variant implies, that the created [authentication key object] has all relevant capabilities for backup related actions (i.e. export-wrapped, wrap-data).

Further, it is assumed that both the [authentication key object] and wrap key object are added to all domains.

Fields

authentication_key_id: Id

The identifier of the authentication key used to create a session with the YubiHSM2.

This represents an authentication key object.

wrapping_key_id: Id

The identifier of the wrapping key in the YubiHSM2 backend.

This identifies the encryption key used for wrapping backups of all keys of the YubiHSM2.

Note

The wrapping key is automatically added to all domains.

ssh_authorized_key: AuthorizedKeyEntry

The SSH public key used for connecting to the system_user.

system_user: SystemUserId

The name of the system user.



HermeticAuditLog

A system user, without SSH access, mapped to a YubiHSM2 authentication key for collecting audit logs.

This variant tracks

Its data is used to create relevant system and backend users for the retrieval of audit logs made available by the YubiHSM2.

Note

This variant implies, that the created authentication key object has all relevant capabilities for audit log retrieval (i.e. get-log-entries).

Fields

authentication_key_id: Id

The identifier of the authentication key used to create a session with the YubiHSM2.

system_user: SystemUserId

The name of the system user.



Signing

A system user, with SSH access, mapped to a YubiHSM2 user in the Operator role with access to a single signing key.

This variant tracks

  • an authentication key object identified by an authentication_key_id
  • a domain (domain) assigned to both objects identified by authentication_key_id and signing_key_id
  • a SigningKeySetup using key_setup
  • an asymmetric key object identified by a signing_key_id
  • an SSH authorized key (ssh_authorized_key) for a system_user
  • a system user ID (system_user)

Its data is used to create relevant system and backend users for the creation of backups of all keys (including authentication key objects) and non-key material (e.g. OpenPGP certificates) of a YubiHSM2.

Note

This variant implies, that the created authentication key object has all relevant capabilities for signing with the asymmetric key object (i.e. sign-ecdsa, sign-eddsa, sign-pkcs and sign-pss).

Further, it is assumed that both the authentication key object and asymmetric key object are added to the single domain domain.

Fields

authentication_key_id: Id

The identifier of the authentication key used to create a session with the YubiHSM2.

key_setup: SigningKeySetup

The setup of a YubiHSM2 key.

domain: Domain

The domain the signing and authentication key belong to.

signing_key_id: Id

The identifier of the signing key in the YubiHSM2 backend.

ssh_authorized_key: AuthorizedKeyEntry

The SSH public key used for connecting to the system_user.

system_user: SystemUserId

The name of the system user.

Implementations

Source

impl YubiHsm2UserMapping

pub fn domain(&self) -> Option<&Domain>

Returns the optional Domain of the YubiHsm2UserMapping.

pub fn backend_user_id(&self) -> Id

Returns the authentication key ID of the YubiHsm2UserMapping.