Error

Enum Error 

pub enum Error {
    NoUsableAdmin,
    DefaultAdminStillUsable,
    Generic {
        context: &'static str,
    },
    DataRetrieval {
        context: &'static str,
        source: Error,
    },
    DuplicateCredentials {
        context: &'static str,
        duplicates: Vec<Id>,
    },
    UserMappingWithoutCredentials {
        context: &'static str,
        ids: Vec<Id>,
    },
    CredentialsWithoutUserMapping {
        context: &'static str,
        ids: Vec<Id>,
    },
    ScenarioLogic {
        context: String,
    },
}
An error that may occur when using YubiHSM2 config objects.

Variants



NoUsableAdmin

There is no usable administrative user on the backend.



DefaultAdminStillUsable

The default administrative credentials are still usable in the backend.



Generic

A generic error.

Fields

context: &'static str

The context in which the error happened.

This is meant to complete the sentence “A generic YubiHSM2 backend error occurred while “.



DataRetrieval

An error occurred while retrieving data from the backend.

Fields

context: &'static str

The reason why data retrieval failed.

This is meant to complete the sentence “YubiHSM2 data retrieval error while “.

source: Error

The error source.



DuplicateCredentials

Encountered duplicate credentials.

Fields

context: &'static str

The context in which the error occurred.

This is meant to complete the sentence “Duplicate credentials {} encountered while “.

duplicates: Vec<Id>

The IDs of duplicate credentials.



UserMappingWithoutCredentials

Encountered user mappings without credentials.

Fields

context: &'static str

The context in which the error occurred.

This is meant to complete the sentence “User mapping without credentials ({}) encountered while “.

ids: Vec<Id>

The IDs of the user mappings without credentials.



CredentialsWithoutUserMapping

Credentials without a matching user mapping found.

Fields

context: &'static str

The context in which the error occurred.

This is meant to complete the sentence “User mapping without credentials ({}) encountered while “.

ids: Vec<Id>

The IDs of the user mappings without credentials.



ScenarioLogic

An error occurred in the logic of a scenario.

Fields

context: String

The reason why the scenario logic failed.

This is meant to complete the sentence “YubiHSM2 scenario logic error because “.