pub struct YubiHsm2BackendState {
pub(crate) user_data: Vec<YubiHsm2BackendUserData>,
pub(crate) key_data: Vec<YubiHsm2BackendUserKeyData>,
}Expand description
The state of a YubiHsm2Backend.
This tracks two lists of data in the backend:
- the authentication keys (“user credentials”), their capabilities and domains
- all other key types, their capabilities, domains, algorithms, labels and lengths
Fields
user_data: Vec<YubiHsm2BackendUserData>The user states.
key_data: Vec<YubiHsm2BackendUserKeyData>The key states.
Implementations
Sourceimpl YubiHsm2BackendState
impl YubiHsm2BackendState
Sourcepub const STATE_NAME: &'static str = "YubiHSM2 backend"
pub const STATE_NAME: &'static str = "YubiHSM2 backend"
The name of the origin for the state.