pub enum UserBackendConnection {
NetHsm {
admin_secret_handling: AdministrativeSecretHandling,
non_admin_secret_handling: NonAdministrativeSecretHandling,
connections: BTreeSet<Connection>,
mapping: NetHsmUserMapping,
},
YubiHsm2 {
admin_secret_handling: AdministrativeSecretHandling,
non_admin_secret_handling: NonAdministrativeSecretHandling,
connections: BTreeSet<Connection>,
mapping: YubiHsm2UserMapping,
},
}Expand description
Backend specific data for a user mapping.
Variants
NetHsm
The connection configuration for a user of a NetHSM backend.
Note
Only supported when using the nethsm feature.
Fields
admin_secret_handling: AdministrativeSecretHandlingAdministrative credentials handling.
non_admin_secret_handling: NonAdministrativeSecretHandlingNon-administrative credentials handling.
mapping: NetHsmUserMappingA specific NetHSM user mapping.
YubiHsm2
The connection configuration for a user of a YubiHSM2 backend.
Note
Only supported when using the yubihsm2 feature.
Fields
admin_secret_handling: AdministrativeSecretHandlingAdministrative credentials handling.
non_admin_secret_handling: NonAdministrativeSecretHandlingNon-administrative credentials handling.
mapping: YubiHsm2UserMappingA specific YubiHSM2 user mapping.
Implementations
Sourceimpl UserBackendConnection
impl UserBackendConnection
Sourcepub fn admin_secret_handling(&self) -> AdministrativeSecretHandling
pub fn admin_secret_handling(&self) -> AdministrativeSecretHandling
Returns the administrative secret handling of this UserBackendConnection.
Sourcepub fn non_admin_secret_handling(&self) -> NonAdministrativeSecretHandling
pub fn non_admin_secret_handling(&self) -> NonAdministrativeSecretHandling
Returns the non-administrative secret handling of this UserBackendConnection.
Sourcepub fn create_non_admin_backend_user_secrets(
&self,
) -> Result<Option<Vec<Box<dyn UserWithPassphrase>>>, Error>
pub fn create_non_admin_backend_user_secrets( &self, ) -> Result<Option<Vec<Box<dyn UserWithPassphrase>>>, Error>
Creates on-disk secrets for non-administrative backend users of the mapping.
Note
Delegates to MappingBackendUserSecrets::create_non_admin_backend_user_secrets.
Errors
Returns an error if MappingBackendUserSecrets::create_non_admin_backend_user_secrets
fails.
Sourcepub fn load_non_admin_backend_user_secrets(
&self,
filter: NonAdminBackendUserIdFilter,
) -> Result<Option<Vec<Box<dyn UserWithPassphrase>>>, Error>
pub fn load_non_admin_backend_user_secrets( &self, filter: NonAdminBackendUserIdFilter, ) -> Result<Option<Vec<Box<dyn UserWithPassphrase>>>, Error>
Loads secrets for each backend user matching a filter.
Note
Delegates to MappingBackendUserSecrets::load_non_admin_backend_user_secrets.
Errors
Returns an error if MappingBackendUserSecrets::load_non_admin_backend_user_secrets
fails.