fn validate_config_against_optional_config<T, U>(
config_a: &Option<T>,
) -> impl FnOnce(&U, &()) -> Result + '_Expand description
Validates a required config object against an optional one.
Ensures that the the two configuration objects have no overlapping system user IDs or SSH authorized_keys.
Errors
Returns an error if there are
- duplicate system users
- duplicate SSH authorized keys (by comparing the actual SSH public keys)