pub struct Config {
system: SystemConfig,
nethsm: Option<NetHsmConfig>,
yubihsm2: Option<YubiHsm2Config>,
}Expand description
The configuration of a Signstar system.
Tracks system-wide configuration items, as well as configurations for specific backends.
Fields
system: SystemConfigSystem configuration object.
nethsm: Option<NetHsmConfig>Optional configuration object for NetHSM backends.
Note
Only supported when using the nethsm feature.
yubihsm2: Option<YubiHsm2Config>Optional configuration object for YubiHSM2 backends.
Note
Only supported when using the yubihsm2 feature.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn user_backend_connection(
&self,
user: &SystemUserId,
) -> Option<UserBackendConnection>
pub fn user_backend_connection( &self, user: &SystemUserId, ) -> Option<UserBackendConnection>
Returns the optional UserBackendConnection matching a SystemUserId.
Sourcepub fn user_backend_connections(
&self,
filter: UserBackendConnectionFilter,
) -> Vec<UserBackendConnection>
pub fn user_backend_connections( &self, filter: UserBackendConnectionFilter, ) -> Vec<UserBackendConnection>
Returns a list of UserBackendConnection objects matching a filter.
Using the UserBackendConnectionFilter filter it is possible to only return
administrative or non-administrative, or all UserBackendConnection objects..
Sourceimpl Config
impl Config
Sourcepub const DEFAULT_CONFIG_DIR: &str = "/usr/share/signstar/"
pub const DEFAULT_CONFIG_DIR: &str = "/usr/share/signstar/"
The default config directory below “/usr/”.
Sourcepub const RUN_OVERRIDE_CONFIG_DIR: &str = "/run/signstar/"
pub const RUN_OVERRIDE_CONFIG_DIR: &str = "/run/signstar/"
The override config directory below “/run/”.
Sourcepub const ETC_OVERRIDE_CONFIG_DIR: &str = "/etc/signstar/"
pub const ETC_OVERRIDE_CONFIG_DIR: &str = "/etc/signstar/"
The override config directory below “/etc/”.
Sourcepub const CONFIG_NAME: &str = "config"
pub const CONFIG_NAME: &str = "config"
The configuration file name (without file type suffix).
Sourcepub fn default_system_path() -> PathBuf
pub fn default_system_path() -> PathBuf
Returns the default location of the Signstar configuration file on a system.
Sourcepub fn first_existing_system_path() -> Result<PathBuf, Error>
pub fn first_existing_system_path() -> Result<PathBuf, Error>
Returns the first found path of a Signstar configuratino on the system.
Errors
Returns an error if no configuration file is found.
Sourcepub fn list_config_dirs() -> Vec<PathBuf>
pub fn list_config_dirs() -> Vec<PathBuf>
Returns the list of supported directory paths in which configuration files may reside.
The returned list of paths is sorted in increasing precedence.
Sourcepub fn list_config_file_paths() -> Vec<PathBuf>
pub fn list_config_file_paths() -> Vec<PathBuf>
Returns the list of supported configuration file paths.
The returned list of paths is sorted in increasing precedence.
Sourcefn from_yaml_str(s: &str) -> Result<Self, Error>
fn from_yaml_str(s: &str) -> Result<Self, Error>
Sourcepub fn from_system_path() -> Result<Self, Error>
pub fn from_system_path() -> Result<Self, Error>
Creates a new Config from the first found Signstar configuration file path on the
system.
Note
Uses Config::first_existing_system_path to determine the first existing Signstar
configuration file path.
Errors
Returns an error if Config creation from the found path fails.
Sourcepub fn to_yaml_string(&self) -> Result<String, Error>
pub fn to_yaml_string(&self) -> Result<String, Error>
Sourcepub fn system(&self) -> &SystemConfig
pub fn system(&self) -> &SystemConfig
Returns a reference to the SystemConfig.
Sourcepub fn nethsm(&self) -> Option<&NetHsmConfig>
pub fn nethsm(&self) -> Option<&NetHsmConfig>
Returns a reference to the NetHsmConfig.
Sourcepub fn yubihsm2(&self) -> Option<&YubiHsm2Config>
pub fn yubihsm2(&self) -> Option<&YubiHsm2Config>
Returns a reference to the YubiHsm2Config.