fn validate_nethsm_config_connections(
value: &BTreeSet<Connection>,
_context: &(),
) -> ResultExpand description
Validates a set of [Connection] objects.
Ensures that value is not empty and does not contain one or more [Connection]s with
duplicate URLs.
Note
[Connection] derives Eq/PartialEq and Ord/PartialOrd, which allows several
items with the same URL but differing TLS settings. However, in a configuration file we
generally never want to use the same device with differing TLS settings, as those devices are
used in a round-robin fashion.
Errors
Returns an error if value is empty or contains one or more [Connection]s with duplicate
URLs.