Function create_unix_users_and_homes
Source fn create_unix_users_and_homes(config: &Config) -> Result<(), Error>
Creates all Unix users and their homes based on a Config.
Errors
Returns an error if any of the Unix users cannot be created.