fn are_admin_creds_usable(
runner: &ScenarioRunner,
credentials: &Credentials,
) -> boolExpand description
Return true if given administrative credentials are currently usable.
Returns false if the credentials cannot be used, have no object information, or do not match
the capabilities or domains they should have.